| Title: | What the Package Does Using Title Case |
|---|---|
| Description: | More details about what the package does. See <http://cran.r-project.org/doc/manuals/r-release/R-exts.html#The-DESCRIPTION-file> for details on how to write this part. |
| Authors: | Your Name |
| Maintainer: | Your Name <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-24 06:04:01 UTC |
| Source: | https://github.com/QingCheng0218/MR.LDP |
More details about what the package does. See <http://cran.r-project.org/doc/manuals/r-release/R-exts.html#The-DESCRIPTION-file> for details on how to write this part.
The DESCRIPTION file:
| Package: | MR.LDP |
| Type: | Package |
| Title: | What the Package Does Using Title Case |
| Version: | 1.0 |
| Date: | 2021-05-31 |
| Author: | Your Name |
| Maintainer: | Your Name <[email protected]> |
| Description: | More details about what the package does. See <http://cran.r-project.org/doc/manuals/r-release/R-exts.html#The-DESCRIPTION-file> for details on how to write this part. |
| License: | GPL (>= 2) |
| Imports: | Rcpp (>= 1.0.4.6) |
| LinkingTo: | Rcpp, RcppArmadillo,BH, bigmemory |
| Repository: | https://mrcieu.r-universe.dev |
| Date/Publication: | 2023-11-27 07:55:49 UTC |
| RemoteUrl: | https://github.com/QingCheng0218/MR.LDP |
| RemoteRef: | HEAD |
| RemoteSha: | 931eb9305fe9f33e53eb5d0bad5df4f74d4d0ff4 |
Index of help topics:
MR.LDP-package What the Package Does Using Title Case
This section should provide a more detailed overview of how to use the package, including the most important functions.
Your Name
Maintainer: Your Name <[email protected]>
This optional section can contain literature or other references for background information.
Optional links to other man pages
## Optional simple examples of the most important functions ## Use \dontrun{} around code to be shown but not executed## Optional simple examples of the most important functions ## Use \dontrun{} around code to be shown but not executed